Small DnD dice package

from DnDice2 import *

or

from DnDice2 import d4, d6, d8, d10, 12, d20, d100, d

has maker function that let's you make new dice:

example:

d50 = maker(50)

d50() "returns 1 - 50"
